import { CanvasTexture, ImageBitmapLoader, TextureLoader, } from "three";
/**
 * Texture image loader, Switching TextureLoader and ImageBitmapLoader.
 */
export class TextureSwitchingLoader {
    constructor(manager) {
        if (TextureSwitchingLoader.isSupportImageBitmap === undefined) {
            TextureSwitchingLoader.isSupportImageBitmap =
                typeof createImageBitmap !== "undefined";
        }
        if (!TextureSwitchingLoader.isSupportImageBitmap) {
            this.textureLoader = new TextureLoader(manager);
        }
        else {
            this.imageBitmapLoader = new ImageBitmapLoader(manager);
            this.imageBitmapLoader.setOptions({ imageOrientation: "flipY" }); //To find the same result TextureLoader and ImageBitmapLoader.
        }
    }
    /**
     * Load image as Texture or CanvasTexture.
     *
     * @param url
     * @param option
     * @return Promise<Texture> Texture or CanvasTexture
     */
    load(url, option) {
        if (option == null) {
            option = {};
        }
        if (TextureSwitchingLoader.isSupportImageBitmap) {
            return this.loadImageBitmap(url, option);
        }
        return this.loadTexture(url, option);
    }
    loadImageBitmap(url, option) {
        return new Promise((resolve, reject) => {
            const onload = (imageBitmap) => {
                const texture = new CanvasTexture(imageBitmap);
                TextureSwitchingLoader.setTextureOptions(texture, option.canvasTextureOption);
                resolve(texture);
            };
            if (option.imageBitmapOption) {
                this.imageBitmapLoader.setOptions(option.imageBitmapOption);
            }
            this.imageBitmapLoader.load(url, onload, undefined, (err) => {
                console.log("TextureSwitchingLoader : ");
                reject(err);
            });
        });
    }
    loadTexture(url, option) {
        return new Promise((resolve, reject) => {
            this.textureLoader.load(url, (texture) => {
                TextureSwitchingLoader.setImageBitmapOptions(texture, option.imageBitmapOption);
                TextureSwitchingLoader.setTextureOptions(texture, option.canvasTextureOption);
                resolve(texture);
            }, undefined, (err) => {
                console.log("TextureSwitchingLoader : ");
                reject(err);
            });
        });
    }
    static setTextureOptions(texture, option) {
        texture.mapping ??= option?.mapping;
        texture.wrapS ??= option?.wrapS;
        texture.wrapT ??= option?.wrapT;
        texture.minFilter ??= option?.minFilter;
        texture.format ??= option?.format;
        texture.type ??= option?.type;
        texture.anisotropy ??= option?.anisotropy;
        texture.colorSpace = option?.colorSpace ?? "srgb";
    }
    static setImageBitmapOptions(texture, imageBitmapOption) {
        const orientation = imageBitmapOption?.imageOrientation;
        if (orientation != null) {
            texture.flipY = orientation === "flipY";
        }
        if (imageBitmapOption?.premultiplyAlpha != null)
            texture.premultiplyAlpha =
                imageBitmapOption.premultiplyAlpha === "premultiply";
    }
}
